using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Logging;
using Serilog;
using Serilog.Extensions.Logging;
using System;

namespace AirBomber
{
    internal static class Program
    {
        /// <summary>
        ///  The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main()
        {
            // To customize application configuration such as set high DPI settings or default font,
            // see https://aka.ms/applicationconfiguration.
            ApplicationConfiguration.Initialize();
            var services = new ServiceCollection();
            ConfigureServices(services);
            using (ServiceProvider serviceProvider = services.BuildServiceProvider())
            {
                try
                {
                    Application.Run(serviceProvider.GetRequiredService<FormMapWithSetAirplanes>());
                }
                catch (Exception ex)
                {
                    GetLogger().Fatal(ex, " .");
                }
            }
        }

        private static Serilog.ILogger GetLogger()
        {
            var configuration = new ConfigurationBuilder()
                .SetBasePath(Directory.GetCurrentDirectory())
                .AddJsonFile(path: "appsettings.json", optional: false, reloadOnChange: true)
                .Build();

            var logger = new LoggerConfiguration()
                .ReadFrom.Configuration(configuration)
                .CreateLogger();
            return logger;
        }
        private static void ConfigureServices(ServiceCollection services)
        {
            services.AddSingleton<FormMapWithSetAirplanes>()
            .AddLogging(option =>
            {
                var logger = GetLogger();
                option.SetMinimumLevel(LogLevel.Information);
                option.AddSerilog(logger);
            });
        }
    }
}